@@ -1,6 +1,8 @@
 from typing import ClassVar
+import inspect
 import datetime
 import logging
+import sqlite3
 from functools import cache
 
 from pydantic import BaseModel
@@ -304,7 +306,7 @@ class Table(metaclass=TableMeta):
         for field in cls._get_fields().values():
             if field.is_reference:
                 for t in (field.base_type, field.secondary_type):
-                    if issubclass(t, Table) and t != Table and t not in created:
+                    if inspect.isclass(t) and issubclass(t, Table) and t != Table and t not in created:
                         t._create_table(created)
         # initialize statements for table creation
         statements = []
@@ -337,10 +339,16 @@ class Table(metaclass=TableMeta):
         new_fields = [field for field in cls._get_fields().values()
                       if field.column_name not in columns_names]
         for field in new_fields:
+            logger.info("ADD COLUMN %s.%s", field.table.__name__, field.name)
             for sql_creation in field.sql_creations:
-                cls._execute(f"ALTER TABLE {cls._get_table_name()} ADD COLUMN {sql_creation}", check=False)
-                if field.is_reference:
-                    raise Exception("cannot add foreign key constraint on existing table")
+                # if sql.
+                # if field.is_reference:
+                #     raise Exception("cannot add foreign key constraint on existing table")
+                try:
+                    cls._execute(f"ALTER TABLE {cls._get_table_name()} ADD COLUMN {sql_creation}", check=False)
+                except sqlite3.OperationalError as error:
+                    if "duplicate column name" not in error.args[0]:
+                        raise
 
     def check_read_only(self, data):
         """Check we are not attempting to alter read-only fields"""
@@ -500,7 +508,7 @@ class Table(metaclass=TableMeta):
         def lazy_loader(self):
             if not name in self.__dict__:
                 model, identifier = self._lazy_joins[name]
-                if issubclass(model, Table):
+                if inspect.isclass(model) and issubclass(model, Table):
                     value = None if identifier is None else model.load(id=identifier)
                 else:
                     value = [reference_type.load(id=reference_id)
