@@ -1,5 +1,6 @@
 import logging
 import types
+import typing
 from copy import copy
 from types import GenericAlias
 
@@ -21,7 +22,9 @@ def to_json_schema(T: type) -> dict:
     if "$defs" in wrapper_schema:
         schema["$defs"] = schema.get("$defs", {}) | wrapper_schema["$defs"]
     # original class name should be shema titles
-    schema["title"] = T.__name__
+    name = getattr(T, "__name__", None)
+    if name is not None:
+        schema["title"] = name
     return schema
 
 def from_json_schema(schema: dict, root_schema: dict=None) -> type:
@@ -44,6 +47,12 @@ def from_json_schema(schema: dict, root_schema: dict=None) -> type:
                 cursor = cursor[key]
         schema |= cursor
 
+    # Is it a union?
+    if "anyOf" in schema:
+        annotations = [from_json_schema(subschema)
+                       for subschema in schema["anyOf"]]
+        return typing.Union[*annotations]
+
     schema_type = schema.get("type")
     title = schema.get("title")
 
@@ -120,13 +129,13 @@ class SuperModel(BaseModel):
                     value = from_json_schema(value)
                 if isinstance(value, type):
                     data[name] = value
-                elif isinstance(value, GenericAlias):
+                elif isinstance(value, (GenericAlias, types.UnionType)):
                     type_data[name] = value
                     data[name] = type(None)
                 elif value is None and not is_required:
                     pass
                 else:
-                    raise ValueError(f"Not a type: {value}")
+                    raise ValueError(f"Not a type: {value} ({type(value)})")
         # validate non-types with BaseModel
         BaseModel.__init__(self, **data)
         # set type attributes without BaseModel check
